From d2eb00d814d80d96907d28f12e03cef3f2e94513 Mon Sep 17 00:00:00 2001
From: Badlop <badlop@process-one.net>
Date: Wed, 12 Mar 2008 23:05:49 +0000
Subject: [PATCH] * src/mod_echo.erl: Small change to avoid a compilation
 warning of unused function

SVN Revision: 1228
---
 ChangeLog        |  5 +++++
 src/mod_echo.erl | 11 +++++++----
 2 files changed, 12 insertions(+), 4 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index d9c945ad5..7df9dfa5f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2008-03-13  Badlop  <badlop@process-one.net>
+
+	* src/mod_echo.erl: Small change to avoid a compilation warning of
+	unused function
+
 2008-03-12  Badlop  <badlop@process-one.net>
 
 	* src/web/ejabberd_web_admin.erl (term_to_string): Show Erlang
diff --git a/src/mod_echo.erl b/src/mod_echo.erl
index 48d373ae4..22875adcd 100644
--- a/src/mod_echo.erl
+++ b/src/mod_echo.erl
@@ -121,7 +121,7 @@ handle_info({route, From, To, Packet}, State) ->
 		"" -> jlib:make_error_reply(Packet, ?ERR_BAD_REQUEST);
 		_ -> Packet
 	end,
-    %%do_client_version(To, From),
+    do_client_version(disabled, To, From), % Put 'enabled' to enable it
     ejabberd_router:route(To, From, Packet2),
     {noreply, State};
 handle_info(_Info, State) ->
@@ -149,8 +149,9 @@ code_change(_OldVsn, State, _Extra) ->
 %% Example of routing XMPP packets using Erlang's message passing
 %%--------------------------------------------------------------------
 
 %% To enable this educational example, uncomment the call to the 
 %% function do_client_version in handle_info.
 
 %% ejabberd provides a method to receive XMPP packets using Erlang's 
 %% message passing mechanism. 
@@ -167,7 +168,9 @@ code_change(_OldVsn, State, _Extra) ->
 %% using exactly the same JID. We add a (mostly) random resource to
 %% try to guarantee that the received response matches the request sent.
 %% Finally, the received response is printed in the ejabberd log file.
-do_client_version(From, To) ->
+do_client_version(disabled, _From, _To) ->
+    ok;
+do_client_version(enabled, From, To) ->
     ToS = jlib:jid_to_string(To),
     %% It is important to identify this process and packet
     Random_resource = integer_to_list(random:uniform(100000)),
@@ -149,8 +149,9 @@ code_change(_OldVsn, State, _Extra) ->
 %%--------------------------------------------------------------------
 
-%% To enable this educational example, uncomment the call to the 
-%% function do_client_version in handle_info.
+%% To enable this educational example, edit the function handle_info:
+%% replace the argument 'disabled' with 'enabled' in the call to the
+%% function do_client_version.
 
 %% ejabberd provides a method to receive XMPP packets using Erlang's 
-- 
2.40.0